@@ -1,7 +1,10 @@
+### Version 2.0: codeYs are no longer returned, but codes are a list
+### with two elements: X and Y.
+
 "bdk" <- function(data, Y, grid = somgrid(), rlen = 100,
                   alpha = c(0.05, 0.01),
                   radius = quantile(nhbrdist, 0.67),
-                  xweight = 0.75,
+                  xweight = 0.75, contin = !(all(rowSums(Y) == 1)),
                   toroidal = FALSE, keep.data = TRUE)
 {
   data <- as.matrix(data)
@@ -11,9 +14,6 @@
   
   if (is.vector(Y)) Y <- matrix(Y, ncol=1)
   ny <- ncol(Y)
-  predict.type <- ifelse (all(rowSums(Y) == 1),
-                          "class",
-                          "continuous")
 
   ng <- nrow(grid$pts)
   xdists <- ydists <- rep(0, ng)  
@@ -21,7 +21,7 @@
   starters <- sample(1:nd, ng, replace = FALSE)
   init <- data[starters, , drop = FALSE]
   codes <- init
-  if (predict.type == "class") {
+  if (!contin) {
     ## rescale to .25 - .75 in order to make class transitions easier
     codeYs <- 0.5 + 0.5*(Y[starters,] - 0.5)
   } else {
@@ -31,7 +31,7 @@
   nhbrdist <- unit.distances(grid, toroidal)
   changes <- rep(0, rlen*2)
 
-  if (predict.type == "continuous") {
+  if (contin) {
     res <- .C("BDK_Eucl",
               data = as.double(data),
               Ys = as.double(Y),
@@ -72,24 +72,22 @@
   }
   
   changes <- matrix(res$changes, ncol=2)
-  codes <- res$codes
-  codeYs <- res$codeYs
-  dim(codes) <- dim(init)
-  dim(codeYs) <- c(ng, ny)
-  colnames(codeYs) <- colnames(Y)
+  codes <- list(X = matrix(res$codes, nrow(init), ncol(init)),
+                Y = matrix(res$codeYs, ng, ny))
+  colnames(codes$Y) <- colnames(Y)
 
   if (keep.data) {
-    mapping <- map.kohonen(list(codes = codes), newdata = data)
+    mapping <- map.kohonen(list(codes = codes), newdata = data, whatmap = 1)
     
-    structure(list(data = data, Y = Y, predict.type = predict.type,
-                   grid = grid, codes = codes, codeYs = codeYs,
+    structure(list(data = data, Y = Y, contin = contin,
+                   grid = grid, codes = codes,
                    changes = changes, toroidal = toroidal,
                    unit.classif = mapping$unit.classif,
                    distances = mapping$distances, method="bdk"),
               class = "kohonen")
   } else {
-    structure(list(predict.type = predict.type,
-                   grid = grid, codes = codes, codeYs = codeYs,
+    structure(list(contin = contin,
+                   grid = grid, codes = codes,
                    changes = changes, toroidal = toroidal, method="bdk"),
               class = "kohonen")
   }
